/*H***************************************************************************
* NAME: AT8XC5123.h           
*----------------------------------------------------------------------------
* PURPOSE: SFR definition - include file for TASKING
*****************************************************************************/
#ifndef _AT8XC5123_H_

#define _AT8XC5123_H_

#define Sfr(x, y)	   _sfrbyte x _at(y)
#define Sbit(x,y,z)	 _sfrbit x _at(y|z)


/*----------------------------- C51 CORE -----------------------------------*/

Sfr (SP      , 0x81);			//Stack Pointer
Sfr (DPL     , 0x82);			//Data Pointer Low byte
Sfr (DPH     , 0x83);			//Data Pointer High Byte

Sfr (PSW     , 0xD0);			//Program Status Word
Sbit (CY     , 0xD0   , 7);		//Carry Flag
Sbit (AC     , 0xD0   , 6);		//Auxilary Carry Flag
Sbit (F0     , 0xD0   , 5);		//Flag 0 available to the user for general purpose
Sbit (RS1    , 0xD0   , 4);		//Register Bank Selector bit 1
Sbit (RS0    , 0xD0   , 3);		//Register Bank Selector bit 0
Sbit (OV     , 0xD0   , 2);		//Overflow Bit
Sbit (F1     , 0xD0   , 1);		//General Purpose Flag
Sbit (P      , 0xD0   , 0);		//Parity Bit

Sfr (A       , 0xE0);			//Accumulator
Sfr (ACC     , 0xE0);			//Accumulator
Sfr (B       , 0xF0);			//B register

/*----------------------- SYSTEM CONFIGURATION -----------------------------*/

Sfr (CKSEL   , 0x85);			//Clock Selection
Sfr (PCON    , 0x87);			//Power Control
Sfr (AUXR    , 0x8E);			//Auxilary Register 0
Sfr (CKCON0  , 0x8F);			//Clock Control Register 0
Sfr (CKRL    , 0x97);			//Clock Reload
Sfr (AUXR1   , 0xA2);			//Auxilary Register 1
Sfr (PLLCON  , 0xA3);			//Phase Lock Loop Control
Sfr (PLLDIV  , 0xA4);			//Phase Lock Loop Divider
Sfr (CKCON1  , 0xAF);			//Clock Control Register 0

/*---------------------------- INTERRUPTS ----------------------------------*/

Sfr (ISEL    , 0xA1);			//Interrupt Enable Control

Sfr (IEN0    , 0xA8);			//Interrupt Enable Control 0
Sbit (EA     , 0xA8  , 7);		//Global Interrupts Enable/Disable Bit
Sbit (ES     , 0xA8  , 4);		//Serial Port Interrupt Enable/Disable Bit
Sbit (ET1    , 0xA8  , 3);		//Timer 1 Overflow Interrupt Enable/Disable Bit
Sbit (EX1    , 0xA8  , 2);		//External Interrupt 1 Enable/Disable Bit
Sbit (ET0    , 0xA8  , 1);		//Timer 0 Overflow Interrupt Enable/Disable Bit
Sbit (EX0    , 0xA8  , 0);		//External Interrupt 0 Enable/Disable Bit

Sfr (IPH0    , 0xB7);			//Interrupt Priority Control High 0

Sfr (IPL0    , 0xB8);			//Interrupt Priority Control Low  0
Sbit (PSL   , 0xB8  , 4);		//Serial Port Interrupt Priority LSB
Sbit (PT1L  , 0xB8  , 3);		//Timer 1 Overflow Interrupt Priority LSB
Sbit (PX1L  , 0xB8  , 2);		//External Interrupt 1 Priority LSB
Sbit (PT0L  , 0xB8  , 1);		//Timer 0 Overflow Interrupt Priority LSB
Sbit (PX0L  , 0xB8  , 0);		//External Interrupt 0 Priority LSB

Sfr (IEN1    , 0xB1);			//Interrupt Enable Control 1
Sfr (IPL1    , 0xB2);			//Interrupt Priority Control Low  1
Sfr (IPH1    , 0xB3);			//Interrupt Priority Control High 1

/*------------------------------- PORTS -----------------------------------*/

Sfr (PMOD1   , 0x84);			//Port Mode Register 1

Sfr (P1      , 0x90);			//Port 1
Sbit (P1_7   , 0x90    , 7);
Sbit (P1_6   , 0x90    , 6);
Sbit (P1_5   , 0x90    , 5);
Sbit (P1_4   , 0x90    , 4);
Sbit (P1_3   , 0x90    , 3);
Sbit (P1_2   , 0x90    , 2);
Sbit (P1_1   , 0x90    , 1);
Sbit (P1_0   , 0x90    , 0);
Sbit (CCLK1  , 0x90    , 7);		//Alternate Card Clock
Sbit (CPRES  , 0x90    , 2);		//Smart Card Presence

Sfr (PMOD0   , 0x91);			//Port Mode Register 0

Sfr (P3      , 0xB0);			//Port 3
Sbit (P3_7   , 0xB0    , 7);
Sbit (P3_6   , 0xB0    , 6);
Sbit (P3_5   , 0xB0    , 5);
Sbit (P3_4   , 0xB0    , 4);
Sbit (P3_3   , 0xB0    , 3);
Sbit (P3_2   , 0xB0    , 2);
Sbit (P3_1   , 0xB0    , 1);
Sbit (P3_0   , 0xB0    , 0);
Sbit (T1     , 0xB0    , 5);		//External Event 1
Sbit (T0     , 0xB0    , 4);		//External Event 0
Sbit (INT1   , 0xB0    , 3);		//External Interrupt 1
Sbit (INT0   , 0xB0    , 2);		//External Interrupt 0
Sbit (TXD    , 0xB0    , 1);		//UART Transmit Port
Sbit (RXD    , 0xB0    , 0);		//UART Receive Port
Sbit (CRST1  , 0xB0    , 5);		//Alternate Card Reset
Sbit (CIO1   , 0xB0    , 4);		//Alternate Card I/O
Sbit (LED3   , 0xB0    , 7);		//Led Number 3
Sbit (LED2   , 0xB0    , 6);		//Led Number 2
Sbit (LED1   , 0xB0    , 4);		//Led Number 1
Sbit (LED0   , 0xB0    , 2);		//Led Number 0

Sfr (P4      , 0xC0);			//Port 4
Sbit (P4_7   , 0xC0    , 7);
Sbit (P4_6   , 0xC0    , 6);

Sfr (P5      , 0xE8);			//Port 5
Sbit (P5_0   , 0xE8    , 0);

/*------------------------------- TIMERS -----------------------------------*/

Sfr (TCON    , 0x88);			//Timer-Counter 0 and 1 Control
Sbit (TF1    , 0x88  , 7);		//Timer 1 Overflow Flag
Sbit (TR1    , 0x88  , 6);		//Timer 1 Run Control Bit
Sbit (TF0    , 0x88  , 5);		//Timer 0 Overflow Flag
Sbit (TR0    , 0x88  , 4);		//Timer 0 Run Control Bit
Sbit (IE1    , 0x88  , 3);		//Interrupt 1 Edge Flag
Sbit (IT1    , 0x88  , 2);		//Interrupt 1 Type Control Bit
Sbit (IE0    , 0x88  , 1);		//Interrupt 0 Edge Flag
Sbit (IT0    , 0x88  , 0);		//Interrupt 0 Type Control Bit

Sfr (TMOD    , 0x89);			//Timer-Counter 0 and 1 Configuration
Sfr (TL0     , 0x8A);			//Timer-Counter 0 Low Byte
Sfr (TL1     , 0x8B);			//Timer-Counter 1 Low Byte
Sfr (TH0     , 0x8C);			//Timer-Counter 0 High Byte
Sfr (TH1     , 0x8D);			//Timer-Counter 1 High Byte

/*------------------------------ WATCHDOG --------------------------------*/

Sfr (WDTRST  , 0xA6);			//WatchDog Timer Reset
Sfr (WDTPRG  , 0xA7);			//WatchDog Timer Program

/*--------------------------- USB CONTROLLER -----------------------------*/

Sfr (UFNUML  , 0xBA);			//USB Frame Number Low
Sfr (UFNUMH  , 0xBB);			//USB Frame Number Low
Sfr (USBCON  , 0xBC);			//USB Global Control
Sfr (USBINT  , 0xBD);			//USB Global Interrupt
Sfr (USBIEN  , 0xBE);			//USB Global Interrupt Enable
Sfr (UEPIEN  , 0xC2);			//USB Endpoint Interrupt Enable
Sfr (USBADDR , 0xC6);			//USB Address
Sfr (UEPNUM  , 0xC7);			//USB Endpoint Number
Sfr (UEPSTAX , 0xCE);			//USB Endpoint X Status
Sfr (UEPDATX , 0xCF);			//USB Endpoint X Fifo Data
Sfr (UEPCONX , 0xD4);			//USB Endpoint X Control
Sfr (UEPRST  , 0xD5);			//USB Endpoint Reset
Sfr (UBYCTX  , 0xE2);			//USB Byte Counter Low (EPX)
Sfr (UEPINT  , 0xF8);			//USB Endpoint Interrupt
Sbit (EP6INT , 0xF8, 6);	
Sbit (EP5INT , 0xF8, 5);		
Sbit (EP4INT , 0xF8, 4);		
Sbit (EP3INT , 0xF8, 3);		
Sbit (EP2INT , 0xF8, 2);		
Sbit (EP1INT , 0xF8, 1);		
Sbit (EP0INT , 0xF8, 0);		

/*------------------------------- SCIB ----------------------------------*/

Sfr (SCTBUF  , 0xAA);			//Smart Card Transmit Buffer (Write Only)			
Sfr (SCRBUF  , 0xAA);			//Smart Card Receive Buffer (read Only)
Sfr (SCSR    , 0xAB);			//Smart Card Selection Register
Sfr (SCCON   , 0xAC);			//Smart Card Interface Contacts
Sfr (SCETU0  , 0xAC);			//Smart Card ETU Register 0
Sfr (SCISR   , 0xAD);			//Smart Card UART Interface Status
Sfr (SCETU1  , 0xAD);			//Smart Card ETU Register 1
Sfr (SCIIR   , 0xAE);			//Smart Card UART Interrupt Identification
Sfr (SCIER   , 0xAE);			//Smart Card UART Interrupt Enable
Sfr (SCWT0   , 0xB4);			//Smart Card Character-Block Waiting Time Register 0
Sfr (SCGT0   , 0xB4);			//Smart Card Transmit Guard Time Register 0
Sfr (SCWT1   , 0xB5);			//Smart Card Character-Block Waiting Time Register 1
Sfr (SCGT1   , 0xB5);			//Smart Card Transmit Guard Time Register 1
Sfr (SCWT2   , 0xB6);			//Smart Card Character-Block Waiting Time Register 2
Sfr (SCICR   , 0xB6);			//Smart Card Interface Control
Sfr (DCCKPS  , 0xBF);			//DC/DC Converter Reload Register
Sfr (SCWT3   , 0xC1);			//Smart Card Character-Block Waiting Time Register 3
Sfr (SCICLK  , 0xC1);			//Smart Card Clock Prescaler

/*------------------------------- UART ---------------------------------*/

Sfr (SCON    , 0x98);			//UART Interface Control
Sbit (SM0    , 0x98  , 7);		//Serial Port Mode Bit 0		
Sbit (FE     , 0x98  , 7);		//Framing error Bit
Sbit (SM1    , 0x98  , 6);		//Serial Port Mode Bit 1
Sbit (SM2    , 0x98  , 5);		//Serial Port Mode Bit 2
Sbit (REN    , 0x98  , 4);		//Reception Enable Bit
Sbit (TB8    , 0x98  , 3);		//Transmitter bit 8
Sbit (RB8    , 0x98  , 2);		//Receiver Bit 8
Sbit (TI     , 0x98  , 1);		//Transmit Interrupt Flag
Sbit (RI     , 0x98  , 0);		//Receive Interrupt Flag

Sfr (SBUF    , 0x99);			//UART Data Buffer
Sfr (SADDR   , 0xA9);			//Slave Address
Sfr (SADEN   , 0xB9);			//Slave Address Mask

/*------------------------ BAUD RATE GENERATOR -------------------------*/

Sfr (BRL     , 0x9A);			//Baud Rate Relaod
Sfr (BDRCON  , 0x9B);			//Baud Rate Control

/*-------------------------------- LED ---------------------------------*/

Sfr (LEDCON0 , 0xF1);			//LED control 0

#endif  /* _AT8XC5123_H_ */
