/*******************************************************************************
* FILE_NAME: LCD.C                                                             
*-------------------------------------------------------------------------------
* FILE_CREATED_BY: Eric TINLOT                                                         
* $Author: $
* $Revision:$
* $Date:$
*-------------------------------------------------------------------------------
* FILE_PURPOSE:  DEMOBOARD BASIC LCD DRIVERS	  
* FILE_CONTENTS:                                                            
*******************************************************************************/

/* Includes     */

#include "config.h" 

  
/*
** ----------------------------------------------------------------------------
** lcd_cmd_wr - write command to LCD
** ----------------------------------------------------------------------------
** Inputs: command
**
**
** Outputs: twice in 4 bit on LCD
**
** ----------------------------------------------------------------------------
** Comments: Use P3.2 and P3.4  to validate lcd  P1.6=R/W=0    P1.7=RS=0
** ----------------------------------------------------------------------------
*/

void lcd_cmd_wr(Uchar value)
{
unsigned char a,b,temp;

    a = (value >> 4) & 0x0F;              /* 4 highest bit of value + RS=RW=0 */
    b =        value & 0x0F;              /* 4 lowest  bit of value + RS=RW=0 */
        
    P1 = a;       		                                                 
    P3 = (P3 & LCD_E);                  /* select  LCD with P3.2=0 and P3.4=0 */
    for(temp=0; temp < 255; temp ++);
    P3 = (P3 | LCD_DIS);                /* Disable LCD with P3.2=1 and P3.4=1 */ 
    
    P1 = b;   		                /* P1.7=0  --> Instruction data input */	
    P3 = (P3 & LCD_E);                  /* select  LCD with P3.2=0 and P3.4=0 */
    for(temp=0; temp < 255; temp ++);
    P3 = (P3 | LCD_DIS);                /* Disable LCD with P3.2=1 and P3.4=1 */ 
 
} 



/*
** ----------------------------------------------------------------------------
** wr_cmd8_lcd - write command to LCD in 8 bits (only 4 low bytes are send) 
** ----------------------------------------------------------------------------
** Inputs: command
**
** Outputs: none
**
** ----------------------------------------------------------------------------
** Comments: Use P3.2 and P3.4  to validate lcd  P1.6=R/W=0    P1.7=RS=0
** ----------------------------------------------------------------------------
*/
void lcd_cmd8_wr(unsigned char value)
{
	Uchar temp;
    P1= value & 0x3F;                         /* 4 low bit of value + RS=RW=0 */
    P3 = (P3 & LCD_E);                  /* select  LCD with P3.2=0 and P3.4=0 */
    for(temp=0; temp < 255; temp ++); 
    P3 = (P3 | LCD_DIS);                /* Disable LCD with P3.2=1 and P3.4=1 */ 
   
} 


/*
** ----------------------------------------------------------------------------
** lcd_init - init LCD to 4 bit mode with 2 lines of 5*7 dots
** ----------------------------------------------------------------------------
** Inputs: none
**
** Outputs: none
**
** ----------------------------------------------------------------------------
** Comments: Use P3.2 and P3.4  to validate lcd  P1.6=R/W=0    P1.7=RS=0
** ----------------------------------------------------------------------------
*/
void lcd_init(void)
{  
   tempo(1);
   tempo(30);              /*  waiting after lcd power supply = 4.5V for 16ms */    
  
   lcd_cmd8_wr(LCD_FCTSET8 | LCD_8BIT);                     /* in mode 8 bits */
   tempo(3);                              /* waiting after lcd Reset for 5 ms */                             
   lcd_cmd8_wr(LCD_FCTSET8 | LCD_8BIT);    
   tempo(1);                     
   lcd_cmd8_wr(LCD_FCTSET8 | LCD_8BIT);      
   lcd_cmd8_wr(LCD_FCTSET8 | LCD_4BIT);                     /* in mode 8 bits */
   lcd_cmd_wr(LCD_FCTSET  | LCD_4BIT | LCD_2_LINE | LCD_5_10DOTS);   
   lcd_cmd_wr(LCD_DISPLAY | LCD_DISP_OFF | LCD_CURS_OFF );  
   lcd_cmd_wr(LCD_SET | LCD_INC );       	
   lcd_cmd_wr(LCD_DISPLAY | LCD_DISP_ON | LCD_CURS_ON );     				     
   lcd_cmd_wr(LCD_CLR);             /* CLEAR ALL DIPLAY with space characters */
   tempo(200);  				     
  
}



/*****************************************************************************
* FUNCTION_NAME: lcd_data_wr                                                             
*----------------------------------------------------------------------------
* FUNCTION_AUTHOR: E.TINLOT                                                         
* FUNCTION_DATE: 06.10.1999                                                           
*----------------------------------------------------------------------------
* FUNCTION_PURPOSE: send a character to the current DDRAM ADRESS                                                          
* FUNCTION_INPUTS:  character                                                          
* FUNCTION_OUTPUTS: none                                                        
*****************************************************************************
* NOTE: 4 higest bit f
irst then 4 lowest bit
**************************
***************************************************/
void lcd_data_wr(Uchar charact)
{
Uchar temp;
    P1 = ((charact >> 4) & LCD_DATA) | LCD_RS;    /* 4 highest bit of charact */
    P3 = P3 & LCD_E ;                                         /* Enabled LCD  */
    for(temp=0; temp < 255; temp ++);
    P3 = P3 | LCD_DIS;                                        /* Disable LCD  */ 
    P1 = (charact & LCD_DATA) | LCD_RS;            /* 4 lowest bit of charact */
    P3 = P3 & LCD_E ;                          
    for(temp=0; temp < 255; temp ++);
    P3 = P3 | LCD_DIS;                
}


/*****************************************************************************
* FUNCTION_NAME: lcd_ddram_init                                                             
*----------------------------------------------------------------------------
* FUNCTION_AUTHOR: E.TINLOT                                                         
* FUNCTION_DATE: 06.10.1999                                                           
*----------------------------------------------------------------------------
* FUNCTION_PURPOSE: init ddram to adress                                                          
* FUNCTION_INPUTS:  adress to init                                                          
* FUNCTION_OUTPUTS: none                                                        
*****************************************************************************
* NOTE: 4 higest bit first then 4 lowest bit
*****************************************************************************/
void lcd_ddram_init(Uchar address)
{   
Uchar temp;
    P1 =  (address | LCD_DDRAM)>>4 ;              /* 4 highest bit of address */
    P3 = P3 & LCD_E ;                                         /* Enabled LCD  */
    for(temp=0; temp < 255; temp ++);
    P3 = P3 | LCD_DIS;                                        /* Disable LCD  */ 
    P1 = address & 0x0F ;                          /* 4 lowest bit of address */
    P3 = P3 & LCD_E ;                          
    for(temp=0; temp < 255; temp ++);
    P3 = P3 | LCD_DIS;                
}








/*****************************************************************************
* FUNCTION_NAME: lcd_wr_line                                                             
*----------------------------------------------------------------------------
* FUNCTION_AUTHOR: E.TINLOT                                                         
* FUNCTION_DATE: 06.10.1999                                                           
*----------------------------------------------------------------------------
* FUNCTION_PURPOSE: send a string of 16 characters (one line) on LCD                                                          
* FUNCTION_INPUTS:  line number and string                                                           
* FUNCTION_OUTPUTS: none                                                        
*****************************************************************************
* NOTE: 
*****************************************************************************/
void lcd_wr_line(Uchar line,Uchar * pt_string)
{
 Uchar i;     
   lcd_cmd_wr(LCD_SET | LCD_INC );       	
   lcd_cmd_wr( 0x10 );              	
  
   if (line==1)                                                 /* first line */
    {  lcd_ddram_init(LCD_LINE_1); 
    	for(i=0;i<16;i++)                                     /* 16 character */
        { 
	lcd_data_wr(pt_string[i]);
        } 
    }

   if (line==2)                                                /* second line */
      { 
       lcd_ddram_init(LCD_LINE_2);                
    	for(i=0;i<16;i++)
        { 
	lcd_data_wr(pt_string[i]);
        }  
    } 

}


/*-------------------------------------------------------------------------------
* FUNCTION_AUTHOR: E. TINLOT                                                         
* FUNCTION_DATE:   06/10/99                                                          
*-------------------------------------------------------------------------------
* FUNCTION_PURPOSE: !! highest priority on timer 0                                                    
* FUNCTION_INPUTS:  none                                                        
* FUNCTION_OUTPUTS: none                                                       
*******************************************************************************/
void tempo(Uint16 number)
{
Uint16 temp1, temp2;
for ( temp1=0; temp1 < number ; temp1++) for (temp2=0; temp2<512; temp2++);
}

